##  Related Information
  * [SAP Signavio Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration?locale=en-US&state=PRODUCTION&version=CLOUD "The integration between SAP LeanIX and SAP Signavio enables seamless data synchronization, ensuring both systems have consistent and up-to-date information about business processes and IT systems. Learn how to set up the integration and how to map and sync data between SAP LeanIX and SAP Signavio.")


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
